@@ -272,7 +272,7 @@ class ClusterManager(object):
         and the ClusterManager, update self
         """
         info = get_deployed_images()
-        fe = get_deployed_frontend()
+        fe = get_deployed_frontend(config=False)
         if not info and not fe:
             secho("Cluster must be new - no existing deployments found!", fg="yellow")
             return
@@ -373,6 +373,7 @@ class ClusterManager(object):
                 run_cmd(f"kubectl delete cm {bk_cm} 2>&1", silent=True)
 
     def diff_version(self, tag=None):
+        self.reconcile()
         tag = tag or self.indico_version
         if not tag or tag.startswith("GIT: "):
             return
