@@ -15,17 +15,11 @@ def find_dependent_services(updated_services: list) -> set:
     to pick up changes. Determined if the services use any of the <updated_confs>
     in their envFrom or volumes.
     """
-    svc_types_to_check = ("statefulset", "deployment", "configmap", "secret")
     updated_confs = [
         ups.split("/", 1)[1]
         for ups in updated_services
         if ups.startswith("secret/") or ups.startswith("configmap/")
     ]
-    updated_services = {
-        ups.split("/", 1)[1]: idx
-        for idx, ups in enumerate(updated_services)
-        if any(ups.startswith(svc_type) for svc_type in svc_types_to_check)
-    }
     # We bank on the fact that names of deployments,
     # statefulsets, configs, secrets are all unique
 
@@ -45,12 +39,7 @@ def find_dependent_services(updated_services: list) -> set:
 
     # 2. For each conf, find the list of dependent resources
     for conf in updated_confs:
-        conf_order = updated_services[conf]
         conf_deps = set([ds.split("  ", 1)[0] for ds in dependency_info if conf in ds])
-        # remove any dependencies that were updated after the conf was updated
-        conf_deps -= set(
-            [cd for cd in conf_deps if updated_services.get(cd, 0) > conf_order]
-        )
         dependent_services.update(conf_deps)
 
     return dependent_services
@@ -151,8 +140,7 @@ def apply(
             dependent_services = find_dependent_services(updated_services)
             if not dependent_services:
                 click.secho(
-                    f"No dependent services found that need to be restarted",
-                    fg="yellow",
+                    "No dependent services found that need to be restarted", fg="yellow"
                 )
                 return
             ctx.invoke(
