@@ -7,6 +7,7 @@ import sys
 from subprocess import Popen, PIPE, STDOUT
 from OpenSSL import crypto, SSL
 from urllib.error import HTTPError
+from onelogin.saml2.idp_metadata_parser import OneLogin_Saml2_IdPMetadataParser
 
 
 from indico_install.utils import options_wrapper, run_cmd, convertb64
@@ -124,55 +125,14 @@ def generate_saml(ctx, host=None, metadata_url=None, custom_saml=None):
             fg="red",
         )
         return
-    try:
-        obj = untangle.parse(metadata_url)
-    except HTTPError:
-        click.secho(
-            "Federation URL not found. Please check that this is the correct URL",
-            fg="red",
-        )
-        return
-    svc = obj.EntityDescriptor.IDPSSODescriptor.SingleSignOnService[0]["Location"]
-    endpoint = obj.EntityDescriptor["entityID"]
-
-    der = base64.b64decode(
-        obj.EntityDescriptor.Signature.KeyInfo.X509Data.X509Certificate.cdata
-    )
-    ssl = Popen(
-        ["openssl", "x509", "-fingerprint", "-inform", "der", "-noout"],
-        stdout=PIPE,
-        stdin=PIPE,
-    )
-    out = ssl.communicate(input=der)[0]
-    bts = out.decode().rstrip().split("=")[1].split(":")[0:20]
-    fin = "".join(bts).lower()
-
-    jac = {
-        "url": "https://" + host + "/auth/users/saml/acs",
-        "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
-    }
-    jsl = {
-        "url": "https://" + host + "/auth/users/saml/sls",
-        "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
-    }
-    jsp = {
-        "entityId": "https://" + host + "/auth/users/saml/metadata",
-        "assertionConsumerService": jac,
-        "singleLogoutService": jsl,
-        "NameIDFormat": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress",
-    }
-    jso = {"url": svc, "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect"}
-    jsu = {"url": svc, "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect"}
-    jid = {
-        "entityId": endpoint,
-        "singleSignOnService": jso,
-        "singleLogoutService": jsu,
-        "certFingerprint": fin,
-    }
-    stg = {"strict": "true", "debug": "true", "sp": jsp, "idp": jid}
+    idp_info = OneLogin_Saml2_IdPMetadataParser.parse_remote(metadata_url)
+    jacs = { "url": "https://" + host + "/auth/users/saml/acs", "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST" }
+    jsls = { "url": "https://" + host + "/auth/users/saml/sls", "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect" }
+    jsp = { "entityId": "https://" + host + "/auth/users/saml/metadata", "assertionConsumerService": jacs, "singleLogoutService": jsls, "NameIDFormat": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress" }
+    stg = { "strict": "true", "debug": "true", "sp": jsp, "idp": idp_info["idp"] }
     settings_content = json.dumps(stg, indent=4)
     run_cmd(
-        f'''kubectl create secret generic indico-sso-secrets --from-literal=settings.json="{settings_content}" ''', silent=True
+        f'''kubectl create secret generic indico-sso-secrets --from-literal=settings.json='{settings_content}' ''', silent=True
         )
     ctx.invoke(restart, services=["noct"], contains=False, wait="2m")
 
