@@ -40,12 +40,6 @@ def check(ctx, *, deployment_root, **kwargs):
 
 @aks.command("create")
 @click.pass_context
-@click.option(
-    "--upload/--no-upload",
-    default=False,
-    help="Upload Indico API data to the Indico file share",
-    show_default=True,
-)
 @options_wrapper()
 def create(ctx, upload=False, *, deployment_root, **kwargs):
     """
@@ -55,5 +49,5 @@ def create(ctx, upload=False, *, deployment_root, **kwargs):
     conf = ctx.obj["TRACKER"].cluster_config
     ask_for_infra_input(conf)
     cluster.create(conf)
-    storage.create(deployment_root, conf, upload=upload)
+    storage.create(deployment_root, conf)
     ctx.obj["TRACKER"].save()
