@@ -114,7 +114,6 @@ def up(ctx, cluster_name):
             for pool in node_pools
         ],
         key=lambda x: bool(x[1]["autoscale"]),
-        reverse=True,
     )
 
     for pool, pool_config in pools:
@@ -174,7 +173,7 @@ def down(ctx, cluster_name):
         run_cmd(
             "kubectl drain --delete-local-data --ignore-daemonsets "
             f"--disable-eviction {node}",
-            slient=True,
+            silent=True,
         )
 
     # 3. Resize node pools
